function [s,frequency] = vna_capture(obj,file)
%VNA_CAPTURE Messwerte auslesen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       file            Dateiname
%   output arguments
%       s               komplexwertige Streuparameter
%       frequency       Messfrequenzen
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-19 bis 3-24
%
%   SCPI-Befehle 
%       CALCulate<Chn>:DATA:STIMulus?
%       [SENSe:]FREQuency:STARt <Frequency>
%       [SENSe:]FREQuency:STOP <Frequency>
%       [SENSe:]SWEep:POINts <SweepPoints>
%       CALCulate<Chn>:DATA SDATa, <data>
%       MEASurement<n>:FORMat <Format>
%       TRACe[:DATA]?
%
%   12.12.2020          T. Weber

switch obj.Name
    case 'none'
        % Messwerte aus Datei lesen
        data = load(file,'-ascii');
        frequency = data(:,1);
        s = data(:,2)+j*data(:,3);
        
    case {'zvl','znle','zvb'}
        % Stimulus auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'CALC1:DATA:STIM?');
        frequency = scanstr(obj,',','%f');

        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'CALC1:DATA? SDAT');
        raw_data = scanstr(obj,',','%f');

        % aus Real- und Imaginrteilen komplexe Streuparameter berechnen
        s = raw_data(1:2:numel(raw_data)-1)+j*raw_data(2:2:numel(raw_data));

        % Messwerte in Datei schreiben
        data = [frequency,real(s),imag(s)];
        save(file,'data','-ascii');
        
    case 'fpc'
        % Stimulus rekonstruieren
        fprintf(obj,'FREQ:STAR?');
        fstart = fscanf(obj,'%f');
        fprintf(obj,'FREQ:STOP?');
        fstop = fscanf(obj,'%f');
        fprintf(obj,'SWE:POIN?');
        n = fscanf(obj,'%d');
        frequency = linspace(fstart,fstop,n)';

        % Betragsmessung aktivieren
        fprintf(obj,'MEAS:FORM MAGN');
        
        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'TRAC?');
        magnitude = scanstr(obj,',','%f');

        % Phasenmessung aktivieren
        fprintf(obj,'MEAS:FORM PHAS');

        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'TRAC?');
        phase = scanstr(obj,',','%f');

        % aus Betrag und Phase komplexe Reflexionsfaktoren berechnen
        s = 10.^(magnitude/20).*exp(j*phase*pi/180);
        
        % Messwerte in Datei schreiben
        data = [frequency,real(s),imag(s)];
        save(file,'data','-ascii');
        
    otherwise
    	error('unsupported VNA');
        
end

end
